.. _tutorial:

Tutorial
========

Let's learn by example.
In this tutorial, we will:

- create and register a Kotti add-on package
- modify the look and feel of Kotti with a simple CSS example
- add content types
- add forms and custom views

.. note::

    If you have questions going through this tutorial, please post a message to the `mailing list`_ or join the `#kotti channel`_ on irc.freenode.net to chat with other Kotti users who might be able to help.

The Tutorial assumes you have a virtualenv named ``mysite`` as described in :ref:`installation`.
It is split into three parts:

.. toctree::
    :maxdepth: 1

    tut-1
    tut-2
    tut-3

.. _mailing list: http://groups.google.com/group/kotti
.. _#kotti channel: irc://irc.freenode.net/#kotti
